@@ -65,6 +65,8 @@ class PyPIConfig:
     """PyPI configuration."""
     publish: bool = True
     repository: str = "pypi"
+    token_env_var: str = "PYPI_TOKEN"  # Default to PYPI_TOKEN for backward compatibility
+    uv_token_env_var: str = "UV_PUBLISH_TOKEN"  # UV-specific token env var
 
 
 @dataclass
